@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-12-17
+# Release 2021-01-07
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.3
+MAKERESOLVEDEB_VERSION=1.4.4
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -18,7 +18,6 @@ check_command() {
 
 copy_object() {
     if [[ -e "$1" ]] ; then
-	#echo "[COPY] $1 [TO] $2"
 	if ! cp -rp "$1" "$2";
 	then
 	    ERRORS=$((ERRORS+1))
@@ -37,7 +36,6 @@ assert_object() {
 }
 
 link_object() {
-    #echo "[LINK] $2 [TO] $1"
     ln -s "$1" "$2"
 }
 
@@ -46,8 +44,8 @@ create_directory() {
 	echo "[ERROR: DIRECTORY EXISTS] $1"
 	ERRORS=$((ERRORS+1))
     else
-	#echo "[CREATE DIRECTORY] $1"
 	mkdir -p "$1"
+	chmod 755 "$1"
     fi
 }
 
@@ -71,7 +69,6 @@ remove_directory() {
 
 extract_tgz() {
     if [[ -f "$1" ]] ; then
-	#echo "[EXTRACT] $1 [TO] $2/$3"
 	tar -zxf "$1" -C "$2" "$3"
     else
 	echo "[ERROR: MISSING] $1"
@@ -79,16 +76,6 @@ extract_tgz() {
     fi
 }
 
-make_executable() {
-    if [[ -e "$1" ]] ; then
-	#echo "[MAKE EXECUTABLE] $1"
-	chmod a+x "$1"
-    else
-	echo "[ERROR: MISSING] $1"
-	ERRORS=$((ERRORS+1))
-    fi
-}
-
 init_deb() {
     create_directory ${DEB_DIR}/DEBIAN
     cat > ${DEB_DIR}/DEBIAN/control <<EOF
@@ -105,10 +92,11 @@ EOF
 }
 
 close_deb() {
+    chmod 644 ${DEB_DIR}/DEBIAN/control
     echo "exit 0" >> ${DEB_DIR}/DEBIAN/postinst
-    make_executable ${DEB_DIR}/DEBIAN/postinst
+    chmod 755 ${DEB_DIR}/DEBIAN/postinst
     echo "exit 0" >> ${DEB_DIR}/DEBIAN/postrm
-    make_executable ${DEB_DIR}/DEBIAN/postrm
+    chmod 755 ${DEB_DIR}/DEBIAN/postrm
 }
 
 process15() {
@@ -430,7 +418,7 @@ installer_extract_xorriso() {
     xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
     if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
     then
-	echo "[ERROR] Failed to extract DaVinci Resolve archive"
+	echo "[ERROR] Failed to extract DaVinci Resolve installer archive"
 	remove_directory ${UNPACK_DIR}
 	exit 1
     fi
@@ -440,10 +428,17 @@ installer_extract_native() {
     # Extract archive
     echo "Extracting archive"
     createf_directory ${UNPACK_DIR}
-    ./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR} >/dev/null
+    chmod a+x ${INSTALLER_ARCHIVE}
+    if [[ ! -x ${INSTALLER_ARCHIVE} ]];
+    then
+	echo "[ERROR] DaVinci Resolve installer archive is not executable"
+	exit 1
+    fi
+    NUMEXTRACT=$(./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR} | grep "^Copied " -c)
+    echo "Found ${NUMEXTRACT} objects"
     if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
     then
-	echo "[ERROR] Failed to extract DaVinci Resolve archive"
+	echo "[ERROR] Failed to extract DaVinci Resolve installer archive"
 	remove_directory ${UNPACK_DIR}
 	exit 1
     fi
